@@ -5,6 +5,7 @@ from .jsons_handler import JsonsHandler
 from .pickle_handler import PickleHandler
 from .yaml_handler import YamlHandler
 from .csv_handler import CsvHandler
+from .tsv_handler import TsvHandler
 from .texts_handler import TextsHandler
 
-__all__ = ['BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler','TextsHandler']
+__all__ = ['BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler','TsvHandler','TextsHandler']
